=========================================
OpenMSIStream 
=========================================

.. image:: ./images/openmsistream_logo.png
   :alt: Open MSI
   :scale: 10 %

OpenMSIStream provides Python applications for generalized laboratory, analysis, and computational materials data streaming using `Apache Kafka <https://kafka.apache.org/>`_. More information is available on :doc:`the Introduction page <installation/introduction>` for new users. OpenMSIStream is maintained as part of the Open Materials Semantic Infrastructure (Open MSI), under NSF award #1921959.

.. image:: https://img.shields.io/pypi/v/openmsistream
   :alt: PyPI 
.. image:: https://img.shields.io/github/license/openmsi/openmsistream
   :alt: GitHub 
.. image:: https://img.shields.io/pypi/pyversions/openmsistream
   :alt: PyPI - Python Version 
.. image:: https://img.shields.io/github/release-date/openmsi/openmsistream
   :alt: GitHub Release Date 
.. image:: https://img.shields.io/github/last-commit/openmsi/openmsistream
   :alt: GitHub last commit 
.. image:: https://img.shields.io/circleci/build/github/openmsi/openmsistream/main
   :alt: CircleCI
.. image:: https://readthedocs.org/projects/openmsistream/badge/?version=latest
   :target: https://openmsistream.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://img.shields.io/badge/linting-pylint-yellowgreen
   :target: https://github.com/PyCQA/pylint
   :alt: linting: pylint

OpenMSIStream is free and open source. It's available on `PyPI <https://pypi.org/project/openmsistream/>`_ and on `GitHub <https://github.com/openmsi/openmsistream>`_. 

The development team can be reached at openmsistream@gmail.com. Please see :doc:`the page on support and contribution <user_info/support_and_contribution>` for ways to get help using OpenMSIStream, as well as information on how to request new functionality or contribute to the project. 

.. toctree::
   :maxdepth: 2
   :caption: Intro to OpenMSIStream:

   introduction/introduction
   introduction/installing_openmsistream
   introduction/tutorials

.. toctree::
   :maxdepth: 2
   :caption: Working with OpenMSIStream:

   user_info/main_programs
   user_info/services
   user_info/encryption
   user_info/troubleshooting
   user_info/support_and_contribution

.. toctree::
   :maxdepth: 2
   :caption: API reference/dev info:

   dev_info/api_reference
   dev_info/ci_testing

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
